==> custom_sastrawi-1.0.4-py3-none-any.whl: custom_sastrawi/Stemmer/StemmerFactory.py <==
import os
from custom_sastrawi.Dictionary.ArrayDictionary import ArrayDictionary
from custom_sastrawi.Stemmer.Stemmer import Stemmer
from custom_sastrawi.Stemmer.CachedStemmer import CachedStemmer
from custom_sastrawi.Stemmer.Cache.ArrayCache import ArrayCache

class StemmerFactory(object):
	""" Stemmer factory helps creating pre-configured stemmer """
	APC_KEY = 'custom_sastrawi_cache_dictionary'

	def create_stemmer(self, isDev=False):
		""" Returns Stemmer instance """

		words = self.get_words(isDev)
		dictionary = ArrayDictionary(words)
		stemmer = Stemmer(dictionary)

		resultCache = ArrayCache()
		cachedStemmer = CachedStemmer(resultCache, stemmer)

		return cachedStemmer

	def create_custom_stemmer(words):
		dictionary = ArrayDictionary(words)
		stemmer = Stemmer(dictionary)

		resultCache = ArrayCache()
		cachedStemmer = CachedStemmer(resultCache, stemmer)

		return cachedStemmer

	def get_words(self, isDev=False):
		#if isDev or callable(getattr(self, 'apc_fetch')):
		#    words = self.getWordsFromFile()
		#else:
		#    words = apc_fetch(self.APC_KEY)
		#    if not words:
		#        words = self.getWordsFromFile()
		#        apc_store(self.APC_KEY, words)
		return self.get_words_from_file()

	def get_words_from_file(self):
		current_dir = os.path.dirname(os.path.realpath(__file__))
		dictionaryFile = current_dir + '/data/kata-dasar.txt'
		if not os.path.isfile(dictionaryFile):
			raise RuntimeError('Dictionary file is missing. It seems that your installation is corrupted.')

		dictionaryContent = ''
		with open(dictionaryFile, 'r') as f:
			dictionaryContent = f.read()

		return dictionaryContent.split('\n')

==> custom_sastrawi-1.0.5-py3-none-any.whl: custom_sastrawi/Stemmer/StemmerFactory.py <==
import os
from custom_sastrawi.Dictionary.ArrayDictionary import ArrayDictionary
from custom_sastrawi.Stemmer.Stemmer import Stemmer
from custom_sastrawi.Stemmer.CachedStemmer import CachedStemmer
from custom_sastrawi.Stemmer.Cache.ArrayCache import ArrayCache

class StemmerFactory(object):
	""" Stemmer factory helps creating pre-configured stemmer """
	APC_KEY = 'custom_sastrawi_cache_dictionary'

	def create_stemmer(self, isDev=False):
		""" Returns Stemmer instance """

		words = self.get_words(isDev)
		dictionary = ArrayDictionary(words)
		stemmer = Stemmer(dictionary)

		resultCache = ArrayCache()
		cachedStemmer = CachedStemmer(resultCache, stemmer)

		return cachedStemmer

	def create_custom_stemmer(self,words):
		dictionary = ArrayDictionary(words)
		stemmer = Stemmer(dictionary)

		resultCache = ArrayCache()
		cachedStemmer = CachedStemmer(resultCache, stemmer)

		return cachedStemmer

	def get_words(self, isDev=False):
		#if isDev or callable(getattr(self, 'apc_fetch')):
		#    words = self.getWordsFromFile()
		#else:
		#    words = apc_fetch(self.APC_KEY)
		#    if not words:
		#        words = self.getWordsFromFile()
		#        apc_store(self.APC_KEY, words)
		return self.get_words_from_file()

	def get_words_from_file(self):
		current_dir = os.path.dirname(os.path.realpath(__file__))
		dictionaryFile = current_dir + '/data/kata-dasar.txt'
		if not os.path.isfile(dictionaryFile):
			raise RuntimeError('Dictionary file is missing. It seems that your installation is corrupted.')

		dictionaryContent = ''
		with open(dictionaryFile, 'r') as f:
			dictionaryContent = f.read()

		return dictionaryContent.split('\n')
